/*
 * STM32F4xx_Framework V1.0
 * @file 	stm32f4xx_Framework.h
 * @brief	This is the unique include file for the STM32F4xx_Framework
 */


/*
 * Supported Devices:
 * 	STM32F40X
 * 	STM32F41X
 *
 * 	This Framework does the minimal configuration of the microcontroller.
 * 	It defines all registers, bits and macros, initializes the Stack and sets up the Vector Table.
 * 	It includes the CMSIS and the ST Standard Peripheral Library to your project.
 * 	After reset the mikrcontroller is running from internal Oscillator without PLL.
 * 	The Framework does NOT configure the clocks! The PLL and Divider defines in stm32f4xx_ClockConfig.h are just
 * 	standard values that can be used in your application for configuring the microcontroller to maximum speed.
 *
 * 	You can configure the Framework through following defines:
 *
 * 		HSE_VALUE			The frequency of the external oscillator.
 * 							Set to -1 if no external oscillator is used. So there is no Clock Check for HSE.
 * 							Standard Value: -1
 *
 * 		HSI_VALUE			The frequency of the internal oscillator.
 * 							Set to -1 if no internal oscillator is used. So there is no Clock Check for HSI.
 * 							Standard Value: 16000000
 *
 * 		PLL_M, PLL_N,		Standard PLL Values that can be used in your application for configuring the clocks to maximum speed.
 * 							The Framework does NOT configure the clocks!
 * 		PLL_P, PLL_Q		If HSE_VALUE is not equal -1, PLL_M is configured as (HSE_VALUE / 2000000);
 * 							else PLL_M is configured as (HSI_VALUE / 2000000). Therefore you do not need to change PLL setting
 * 							if you are using another HSE Oscillator.
 * 							Standard Values:	PLL_M: 	(HSE_VALUE or HSI_VALUE / 2000000)
 * 												PLL_N:	168
 * 												PLL_P: 	2
 * 												PLL_Q:	7
 *
 * 		HCLK_DIV,			Standard Prescalers that can be used in your application for configuring the Bus-Frequencies to maximal speed when SYSCLK = 168MHz.
 * 		PCLK1_DIV,			The Framework does NOT configure the clocks!
 * 		PCLK2_DIV
 *
 * 		HSE_STARTUP_TIMEOUT	Timeout for HSE.
 * 							Standard Value: 0x0500
 *
 * 		STACK_SIZE			Configures the Stack Size (In Words).
 * 							Standard Value: 0x00000200
 *
 * 		VECT_TAB_OFFSET		Offset of the Vector Table.
 * 							Standard Value: 0x00
 *
 * 		VECT_TAB_SRAM		Locate the Vector Table in SRAM.
 * 							Standard Value: UNDEFINED (Vector Table in FLASH)
 *
 * 		__FPU_USED			If __FPU_USED is defined the Framework will enable the FPU.
 * 							Standard Value: UNDEFINED (FPU is disabled)
 *
 * 		USE_FULL_ASSERT		Enable full assert (Used in ST Standard Peripheral Library).
 * 							You have to add the function void assert_failed(uint8_t* file, uint8_t line)
 * 							to handle wrong parameters in ST Standard Peripheral Library
 */


/*----------Define to prevent recursive inclusion-----------------------------*/
#ifndef __STM32F4XX_FRAMEWORK_H
#define __STM32F4XX_FRAMEWORK_H


/*----------Include----------------------------------------------------------*/
#include "stm32f4xx.h"

#endif
